@@ -3,11 +3,12 @@
 from __future__ import with_statement
 from __future__ import division
 
-try:
-	import PySide.QtCore as _QtCore
-	QtCore = _QtCore
-	USES_PYSIDE = True
-except ImportError:
+#try:
+#	import PySide.QtCore as _QtCore
+#	QtCore = _QtCore
+#	USES_PYSIDE = True
+#except ImportError:
+if True:
 	import sip
 	sip.setapi('QString', 2)
 	sip.setapi('QVariant', 2)
